@@ -464,7 +464,7 @@ void MainWindow::on_btnSav_clicked()
 void MainWindow::on_btnLoad_clicked()
 {
     QString fullLine;
-    QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"",tr("Pusher level file (*.psh)"));
+    QString fileName = QFileDialog::getOpenFileName(this, tr("Open File"),"/home/user/MyDocs/",tr("Pusher level file (*.psh)"));
     QFile file(fileName);
     if (!file.open(QIODevice::ReadOnly | QIODevice::Text)){
 	//showmessage that file is corrupted
