@@ -40,8 +40,9 @@ private slots:
     void on_btnSave_pressed();
     void on_btnClear_pressed();
     void on_btnApply_clicked();
-    void on_btnSave_clicked();
     void on_btnSav_clicked();
+    void on_btnLoad_clicked();
+    void drawLevel();
 };
 
 #endif // MAINWINDOW_H
